You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2017/11/07 10:11:57 UTC

[sling-org-apache-sling-scripting-sightly-models-provider] 08/13: SLING-6028 - Replace Sightly references with HTL in both code and documentation

This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to annotated tag org.apache.sling.scripting.sightly.models.provider-1.0.2
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-scripting-sightly-models-provider.git

commit 579c1f0f0b46839a846b46742b201c79c3040c74
Author: Radu Cotescu <ra...@apache.org>
AuthorDate: Fri Sep 2 14:51:07 2016 +0000

    SLING-6028 - Replace Sightly references with HTL in both code and documentation
    
    git-svn-id: https://svn.apache.org/repos/asf/sling/trunk/bundles/scripting/sightly/models-use-provider@1758968 13f79535-47bb-0310-9956-ffa450edef68
---
 README.md                                                          | 6 ++++++
 pom.xml                                                            | 7 ++++---
 .../scripting/sightly/models/impl/SlingModelsUseProvider.java      | 4 ++--
 3 files changed, 12 insertions(+), 5 deletions(-)

diff --git a/README.md b/README.md
new file mode 100644
index 0000000..5cc4c9b
--- /dev/null
+++ b/README.md
@@ -0,0 +1,6 @@
+Apache Sling Scripting HTL Sling Models Use Provider
+==================================================
+
+The Apache Sling Scripting HTL Sling Models Use Provider adds support for accessing
+[Sling Models](https://sling.apache.org/documentation/bundles/models.html)
+from HTL's Use-API leveraging the `ModelFactory`.
diff --git a/pom.xml b/pom.xml
index d601f41..cff5b2b 100644
--- a/pom.xml
+++ b/pom.xml
@@ -36,10 +36,11 @@
     <version>1.0.1-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Models Use Provider</name>
+    <name>Apache Sling Scripting HTL Sling Models Use Provider</name>
 
     <description>
-        Apache Sling Scripting Sightly Models Use Provider adds support for accessing Sling Models from Sightly's Use-API leveraging the ModelFactory.
+        Apache Sling Scripting HTL Sling Models Use Provider adds support for accessing Sling Models from HTL's Use-API leveraging the
+        ModelFactory.
     </description>
 
     <scm>
@@ -96,7 +97,7 @@
             <scope>provided</scope>
         </dependency>
 
-        <!-- Sightly -->
+        <!-- HTL -->
         <dependency>
             <groupId>org.apache.sling</groupId>
             <artifactId>org.apache.sling.scripting.sightly.compiler.java</artifactId>
diff --git a/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java b/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java
index 38a0e00..1de27bf 100644
--- a/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java
+++ b/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java
@@ -41,7 +41,7 @@ import org.slf4j.LoggerFactory;
 
 /**
  * <p>
  * Sightly {@link UseProvider} which will instantiate a referenced Sling Model.
  * </p>
  * <p>
  * For that it tries to use the {@link ModelFactory#createModel(Object, Class)} first with the adaptable {@link SlingHttpServletRequest}
@@ -59,7 +59,7 @@ import org.slf4j.LoggerFactory;
  */
 @Component(
     metatype = true,
-    label = "Apache Sling Scripting Sightly Sling Models Use Provider",
+    label = "Apache Sling Scripting HTL Sling Models Use Provider",
     description = "The Sling Models Use Provider is responsible for instantiating Sling Models to be used with Sightly's Use-API."
 )
 @Service
@@ -41,7 +41,7 @@ import org.slf4j.LoggerFactory;
 /**
  * <p>
- * Sightly {@link UseProvider} which will instantiate a referenced Sling Model.
+ * HTL {@link UseProvider} which will instantiate a referenced Sling Model.
  * </p>
  * <p>

-- 
To stop receiving notification emails like this one, please contact
"commits@sling.apache.org" <co...@sling.apache.org>.